@@ -54,14 +54,14 @@ TEMPLATE_TYPENAME(T)
 inline T *lvi_cast(QTreeWidgetItem *item)
 {
     return item && (item->type() == T::RTTI)
-           ? static_cast<T *>(item) : 0;
+           ? static_cast<T *>(item) : nullptr;
 }
 
 TEMPLATE_TYPENAME(T)
 inline const T *lvi_cast(const QTreeWidgetItem *item)
 {
     return item && (item->type() == T::RTTI)
-           ? static_cast<const T *>(item) : 0;
+           ? static_cast<const T *>(item) : nullptr;
 }
 #undef TEMPLATE_TYPENAME
 
@@ -74,7 +74,7 @@ public:
     KeyListViewItem(KeyListView *parent, KeyListViewItem *after, const GpgME::Key &key);
     KeyListViewItem(KeyListViewItem *parent, const GpgME::Key &key);
     KeyListViewItem(KeyListViewItem *parent, KeyListViewItem *after, const GpgME::Key &key);
-    ~KeyListViewItem();
+    ~KeyListViewItem() override;
 
     void setKey(const GpgME::Key &key);
     const GpgME::Key &key() const
@@ -141,8 +141,8 @@ public:
     };
 
     explicit KeyListView(const ColumnStrategy *strategy,
-                         const DisplayStrategy *display = 0,
-                         QWidget *parent = nullptr, Qt::WindowFlags f = 0);
+                         const DisplayStrategy *display = nullptr,
+                         QWidget *parent = nullptr, Qt::WindowFlags f = {});
 
     ~KeyListView();
 
@@ -215,9 +215,9 @@ private:
     void deregisterItem(const KeyListViewItem *);
 
 private:
-    const ColumnStrategy *mColumnStrategy;
-    const DisplayStrategy *mDisplayStrategy;
-    bool mHierarchical;
+    const ColumnStrategy *mColumnStrategy = nullptr;
+    const DisplayStrategy *mDisplayStrategy = nullptr;
+    bool mHierarchical = false;
 
     class Private;
     Private *const d;
